@@ -1,13 +1,20 @@
 #pragma once
 
 #include <string>
+#include <tuple>
 #include <vector>
 
 namespace caracal {
 
+using MPLSLabel = std::tuple<uint32_t, uint8_t, uint8_t, uint8_t>;
+
 /// A traceroute reply (all values are in host order, including the IP
 /// addresses).
 struct Reply {
+  /// @name Capture attributes
+  /// @{
+  int64_t capture_timestamp;  ///< The capture timestamp in microseconds.
+  /// @}
   /// @name Reply attributes (IP)
   /// @{
   in6_addr reply_src_addr;  ///< The source IP of the reply packet.
@@ -22,8 +29,9 @@ struct Reply {
   /// @{
   uint8_t reply_icmp_type;  ///< ICMP type (0 if not an ICMP reply)
   uint8_t reply_icmp_code;  ///< ICMP code (0 if not an ICMP reply)
-  std::vector<uint32_t> reply_mpls_labels;  ///< MPLS labels contained in the
-                                            ///< ICMP extension.
+  std::vector<MPLSLabel>
+      reply_mpls_labels;  ///< MPLS labels contained in the
+                          ///< ICMP extension (label, exp, stack bit, ttl).
   /// @}
 
   /// @name Probe attributes (IP → ICMP → IP)
@@ -68,7 +76,9 @@ struct Reply {
 
   /// Serialize the reply in the CSV format.
   /// @return the reply in CSV format.
-  [[nodiscard]] std::string to_csv() const;
+  [[nodiscard]] std::string to_csv(const std::string &round) const;
+
+  [[nodiscard]] static std::string csv_header();
 };
 
 std::ostream &operator<<(std::ostream &os, Reply const &v);
